==> ulyxex.1.1.0.with-tinyMce.zip: pages/core/ulyxex.php <==
<?php
/* Ulyxex version 1.1.0 *****************/
class Ulyxex {
	public function q($query=Null){
		if (isset($_SESSION['countqueries'])) $_SESSION['countqueries']++;
		// add ";" if not
		$query = trim($query);
		if (substr($query,-1) != ";") $query .= ";";
		$dbLink = @mysqli_connect(HOSTMYSQL,USERMYSQL,PASSMYSQL,BASEMYSQL) or die("Error database connection aborted"); 
		$result = $dbLink->query($query) or die("Error in query");
		mysqli_close($dbLink);
		return $result;
	}
	public function fetch($query=Null){
		return @mysqli_fetch_assoc($query);
	}
	public function Where($And=array()){
		$data = "";
		if (count($And) > 0) $data = " WHERE ".implode(" AND ",$And);
		return $data;
	}
	public function home_params(){
		$query = "SELECT * FROM ".PARAMS." WHERE ID=1;";
		$query = $this->q($query);
		if ($result = $this->fetch($query)){
			return $result;
		} else {
			exit("error home_params !");
		}
	}
	public function art_params($id){
		$query = "SELECT ID,USERID,HIDE,PAGEID FROM ".ARTICLES." WHERE ID = ".$id;
		$query = $this->q($query);
		if ($result = $this->fetch($query)){
			return $result;
		} else {
			exit("error art_params !");
		}
	}
	public function page_params($id){
		$query = "SELECT * FROM ".PAGES." WHERE ID=".$id;
		$query = $this->q($query);
		if ($result = $this->fetch($query)){
			return $result;
		} else {
			exit("error page_params !");
		}
	}
	public function link_params($id){
		$query = "SELECT * FROM ".LINKS." WHERE ID=".$id;
		$query = $this->q($query);
		if ($result = $this->fetch($query)){
			return $result;
		} else {
			exit("error link_params !");
		}
	}
	public function user_params($id){
		$query = "SELECT * FROM ".USERS." WHERE ID=".$id;
		$query = $this->q($query);
		if ($result = $this->fetch($query)){
			return $result;
		} else {
			exit("error user_params !");
		}
	}
}
?>

==> ulyxex.1.2.0.with-tinyMce.zip: pages/core/ulyxex.php <==
<?php
/* Ulyxex version 1.2.0 *****************/
if (!defined('VERSION')) {
	define("VERSION","1.2.0");
}
class Ulyxex {
	public function q($query=Null,$debug=0){
		if (isset($_SESSION['countqueries'])) $_SESSION['countqueries']++;
		// add ";" if not
		$query = trim($query);
		if (substr($query,-1) != ";") $query .= ";";
		$dbLink = @mysqli_connect(HOSTMYSQL,USERMYSQL,PASSMYSQL,BASEMYSQL) or die("Error database connection aborted"); 
		if ($debug) {// debug
			$result = $dbLink->query($query) or die("Error in query".": ".$query); 
		} else {
			$result = $dbLink->query($query) or die("Error in query");
		}
		mysqli_close($dbLink);
		return $result;
	}
	public function qTest($query=Null){
		if (isset($_SESSION['countqueries'])) $_SESSION['countqueries']++;
		// add ";" if not
		$query = trim($query);
		if (substr($query,-1) != ";") $query .= ";";
		$dbLink = @mysqli_connect(HOSTMYSQL,USERMYSQL,PASSMYSQL,BASEMYSQL) or die("Error database connection aborted"); 
		$result = $dbLink->query($query);
		if ($result) {
			$result = "<span style='color:green;' >OK >>>> ".$query."</span>";
		} else {
			$result = "<span style='color:red;' >NOT >>> ".$query."</span>";
		}
		mysqli_close($dbLink);
		return $result;
	}
	public function fetch($query=Null){
		return @mysqli_fetch_assoc($query);
	}
	public function Where($And=array()){
		$data = "";
		if (count($And) > 0) $data = " WHERE ".implode(" AND ",$And);
		return $data;
	}
	public function home_params(){
		$query = "SELECT * FROM ".PARAMS." WHERE ID=1;";
		$query = $this->q($query);
		if ($result = $this->fetch($query)){
			return $result;
		} else {
			exit("error home_params !");
		}
	}
	public function art_params($id){
		$query = "SELECT ID,USERID,HIDE,PAGEID FROM ".ARTICLES." WHERE ID = ".$id;
		$query = $this->q($query);
		if ($result = $this->fetch($query)){
			return $result;
		} else {
			exit("error art_params !");
		}
	}
	public function page_params($id){
		$query = "SELECT * FROM ".PAGES." WHERE ID=".$id;
		$query = $this->q($query);
		if ($result = $this->fetch($query)){
			return $result;
		} else {
			exit("error page_params !");
		}
	}
	public function user_params($id){
		$query = "SELECT * FROM ".USERS." WHERE ID=".$id;
		$query = $this->q($query);
		if ($result = $this->fetch($query)){
			return $result;
		} else {
			exit("error user_params !");
		}
	}
	public function level($level=0){
		if ($_SESSION['level'] > $level) {
			exit("bad user level !");
		} else {
			return;
		}
	}
}
?>
